@@ -7,15 +7,13 @@ from fastapi import APIRouter, Depends, Response
 from fastapi.responses import HTMLResponse
 from fastapi.staticfiles import StaticFiles
 from fps.hooks import register_router  # type: ignore
-from fps_auth.backends import current_user  # type: ignore
-from fps_auth.config import get_auth_config  # type: ignore
-from fps_auth.db import get_user_db  # type: ignore
-from fps_auth.models import UserRead  # type: ignore
 from fps_lab.config import get_lab_config  # type: ignore
 from fps_lab.routes import init_router  # type: ignore
 from fps_lab.utils import get_federated_extensions  # type: ignore
 from starlette.requests import Request  # type: ignore
 
+from jupyverse import User, current_user, update_user
+
 from .config import get_jlab_config
 
 router = APIRouter()
@@ -37,26 +35,23 @@ router.mount(
 
 @router.get("/lab")
 async def get_lab(
-    user: UserRead = Depends(current_user),
+    user: User = Depends(current_user()),
     lab_config=Depends(get_lab_config),
-    auth_config=Depends(get_auth_config),
 ):
     return HTMLResponse(
-        get_index("default", auth_config.collaborative, config.dev_mode, lab_config.base_url)
+        get_index("default", lab_config.collaborative, config.dev_mode, lab_config.base_url)
     )
 
 
 @router.get("/lab/tree/{path:path}")
-async def load_workspace(
-    path, lab_config=Depends(get_lab_config), auth_config=Depends(get_auth_config)
-):
+async def load_workspace(path, lab_config=Depends(get_lab_config)):
     return HTMLResponse(
-        get_index("default", auth_config.collaborative, config.dev_mode, lab_config.base_url)
+        get_index("default", lab_config.collaborative, config.dev_mode, lab_config.base_url)
     )
 
 
 @router.get("/lab/api/workspaces/{name}")
-async def get_workspace_data(user: UserRead = Depends(current_user)):
+async def get_workspace_data(user: User = Depends(current_user())):
     if user:
         return json.loads(user.workspace)
     return {}
@@ -68,21 +63,21 @@ async def get_workspace_data(user: UserRead = Depends(current_user)):
 )
 async def set_workspace(
     request: Request,
-    user: UserRead = Depends(current_user),
-    user_db=Depends(get_user_db),
+    user: User = Depends(current_user()),
+    user_update=Depends(update_user),
 ):
-    await user_db.update(user, {"workspace": await request.body()})
+    workspace = (await request.body()).decode("utf-8")
+    await user_update({"workspace": workspace})
     return Response(status_code=HTTPStatus.NO_CONTENT.value)
 
 
 @router.get("/lab/workspaces/{name}", response_class=HTMLResponse)
 async def get_workspace(
     name,
-    user: UserRead = Depends(current_user),
+    user: User = Depends(current_user()),
     lab_config=Depends(get_lab_config),
-    auth_config=Depends(get_auth_config),
 ):
-    return get_index(name, auth_config.collaborative, config.dev_mode, lab_config.base_url)
+    return get_index(name, lab_config.collaborative, config.dev_mode, lab_config.base_url)
 
 
 INDEX_HTML = """\
